%% Demo4: Rational-Dilation Overcomplete Wavelet Transform
% Show wavelets for various (p,q,s) values.
%
% Ivan Selesnick, Polytechnic Institute, Brooklyn, New York.
% November 2009

%% Set parameters
% p, q, s, Levels should all be non-negative integers and p < q.
% Also, p, q, s should be chosen so that the redundancy > 1.

clear
addpath radwt_functions_v2          % or use 'radwt_functions_v1'
addpath extra_functions

params = [
        2   3   1   5
        3   4   2   10
        4   5   2   10
        4   5   3   10
        5   6   2   15
        5   6   3   15
        6   7   2   15
        6   7   3   15
        6   7   4   15
        7   8   2   17
        7   8   3   18
        7   8   4   18
        7   8   5   18
        8   9   2   17
        8   9   3   17
        8   9   4   18
        8   9   5   18
        11  12  4   22
        11  12  5   22
        15  16  5   25
        15  16  4   30
        ];

for k = 1:size(params,1)    
             
    p = params(k,1);
    q = params(k,2);
    s = params(k,3);
    
    redundancy = 1/s * 1/(1-p/q)        % Must be greater than 1

    % Check perfect reconstruction (PR) of wavelet transform

    N = 250;                    % Length of test signal
    J = 10;
    x = rand(1,N);                  % Make test signal
    w = radwt(x,J,p,q,s);           % Forward overcomplete rational WT
    y = iradwt(w,p,q,s);            % Inverse overcomplete rational WT
    y = real(y(1:N));               % Reconstructed signal
    e = max(abs(x - y));            % Error should be zero
    disp(e)

    % Plot wavelets at multiple scales
    % Display the wavelets for the first several levels.

    N = 250;                            % Length of signal
    J1 = 3; J2 = 10;

    subplot(4,1,1)
    J = params(k,4);
    Plot_FreqResps(p,q,s,J)

    subplot(4,1,2:4)
    PlotWavelets(N,p,q,s,J1,J2);
    
    
    orient tall

    if k == 1
        print -dpsc figures/wavelet_pqs
    else
        print -append -dpsc figures/wavelet_pqs
    end

end
