function y = PlotReconSubbands(x, w, p, q, s, Fs)
% y = PlotReconSubbands(x, w, p, q, s)
% Reconstruct signal x from one subband at a time.
% These reconstructed subband signals add up exactly to the
% original signal x.
%
% Use PlotReconSubbands(x, w, p, q, s, Fs) to specify
% sampling frequency


if nargin < 6
    Fs = 1;
end

J = length(w) - 1;
wz = radwt(0*x, J, p, q, s);        % All-zero wavelet coefficients
N = length(x);
y = cell(1,J+1);

M = max(abs(x));

clf
plot([1:N]/Fs,x/M)
hold on
for j = 1:J+1
    w2 = wz;                        % Set w to all-zero coefficients
    w2{j} = w{j};                   % Set single subband
    y{j} = iradwt(w2,p,q,s);        % Inverse rational WT
    y{j} = real(y{j}(1:N));         % Reconstructed signal
    plot([1:N]/Fs,y{j}/M-j,'k')       % Plot signal
end
hold off
xlim([0 N]/Fs)
ylim([-J-2 1.2])
set(gca,'Ytick',-J-1:-1,'YtickLabel',[J+1:-1:-1])
title('RECONSTRUCTION OF A SIGNAL FROM INDIVIDUAL SUBBANDS')
ylabel('SUBBAND')

if nargin < 6
    xlabel('TIME (SAMPLES)')
else
    xlabel('TIME (SECONDS)')
end

