function PlotWavelets(N,p,q,s,J1,J2,fs)
% PlotWavelets(N,p,q,s,J1,J2)
% Plots wavelets from scales J1 to J2 for an N-point signal

% PlotWavelets(N,p,q,s,J1,J2,fs)
% samples at fs samples/second.

if nargin < 7
    fs = 1;
end

figure(gcf)

red = 1/s * 1/(1-p/q);              % Redundancy

z = zeros(1,N);                     % Zero signal
wz = radwt(z,J2,p,q,s);             % All zero wavelet coefficients
% clf
for j = J1:J2
    w = wz;                         % Set w to all-zero coefficients
    m = ceil((p/q)^(j-1)/s*N/2);    % Index at level j for n = N/2
    w{j}(m) = 1;                    % Set single wavelet coefft to 1
    y = iradwt(w,p,q,s);            % Inverse rational WT
    y = real(y(1:N));               % Reconstructed signal
    M = 2.5*max(abs(y));
    plot([1:N]/fs,y/M-j)            % Plot wavelet
    hold on
end
ylim([-J2-1 -J1+1])

hold off
xlim([0 N]/fs)
if nargin < 7
    xlabel('TIME (SAMPLES)')
else
    xlabel('TIME (SECONDS)')
end


set(gca,'Ytick',-J2:-J1,'YtickLabel',[J2:-1:J1])
ylabel('SUBBAND')
title('THE WAVELET AT SEVERAL SCALES')

txt = sprintf('P = %d, Q = %d, S = %d',p,q,s);
text(0,-0.05,txt,'units','normalized');

txt = sprintf('Dilation = %.2f, Redundancy = %.2f',q/p, red);
text(1,-0.05,txt,'units','normalized','horizontalalignment','right');

