function Plot_FreqResps(p,q,s,J,Fs)
% Plot_FreqResps(p,q,s,Levels)
% Plot frequency responses of the rational-dilation
% wavelet transform (RADWT) with parameters (p,q,s).
%
% Use Plot_FreqResps(p,q,s,Levels,Fs) to specify
% sampling frequency

figure(gcf)

if nargin < 5
    Fs = 1;
end

for j = 1:J
    w2 = (p/q)^(j-1) * pi;
    w1 = (1-1/s) * w2;
    w = linspace(w1,w2,70);
    G = Gjbar_fun(w,p,q,s,j);
    plot(w/pi/2*Fs,G);
    hold on
end
% plot([0 0.5*Fs],[0 0])
hold off
set(gca,'Xtick',[0:0.1:0.5]*Fs)
box off
xlim([0 0.5*Fs])
ylim([0 1.2*max(G)])
% keyboard
txt = sprintf('RADWT FREQUENCY RESPONSES (P = %d, Q = %d, S = %d, %d LEVELS)',p,q,s,J);
title(txt)
if nargin < 5
    xlabel('FREQUENCY (CYCLES/SAMPLE)')
else
    xlabel('FREQUENCY (HERZ)')
end

% txt = sprintf('p = %d, q = %d, s = %d',p,q,s);
% text(0.3,max(G), txt)
% title('RADWT FREQUENCY RESPONSES')


% --- LOCAL FUNCTION ---

function G = Gjbar_fun(w,p,q,s,j)

% G = Gjbar_fun(w,p,q,s,j)
% Equation (41) in RADWT-FFT paper (Aug 2009, IEEE TSP)

G = Hjbar_fun(w,p,q,s,j-1) .* G_fun(w * (q/p)^(j-1), p,q,s);


% --- LOCAL FUNCTION ---

function H = Hjbar_fun(w,p,q,s,j)

% H = Hjbar_fun(w,p,q,s,j)
% Equation (37) in RADWT-FFT paper (Aug 2009, IEEE TSP)

H = (abs(w) <= pi*(p/q)^j);

for k = 0:j-1
    H = H .* H_fun((q/p)^(j-k)*w/q,p,q,s);
end

H = H / (p^j);


% --- LOCAL FUNCTION ---

function G = G_fun(w,p,q,s)

% G = G_fun(w,p,q,s)
% Equation (27) in RADWT-FFT paper (Aug 2009, IEEE TSP)


G = zeros(size(w));

w = mod(w+pi,2*pi)-pi;

G = sqrt(s) * (abs(w) >= p*pi/q) .* (abs(w) <= pi);

k = (abs(w) >= (1-1/s)*pi) & (abs(w) <= p*pi/q);

a = (1-1/s)*pi/p;
b = 1/q - (1-1/s)/p;

G(k) = sqrt(s)*  sqrt(1-theta_fun((w(k)-p*a)/(p*b)).^2)   ;


% --- LOCAL FUNCTION ---

function theta = theta_fun(w)

% theta = theta_fun(w)
% Equation (28) in RADWT-FFT paper (Aug 2009, IEEE TSP)

theta = 0.5 * (1 + cos(w)) .* sqrt(2-cos(w));


% --- LOCAL FUNCTION ---

function H = H_fun(w,p,q,s)

% H = H_fun(w,p,q,s)
% Equation (26) in RADWT-FFT paper (Aug 2009, IEEE TSP)

H = zeros(size(w));

w = mod(w+pi,2*pi)-pi;

H = sqrt(p*q) * (abs(w) <= (1-1/s)*pi/p);

k = (abs(w) >= (1-1/s)*pi/p) & (abs(w) <= pi/q);

a = (1-1/s)*pi/p;
b = 1/q - (1-1/s)/p;

H(k) = sqrt(p*q)*theta_fun((w(k)-a)/b);





