function y = sfb(lo, hi, H, G, p, q, s)
% y = sfb(lo, hi, H, G, p, q, s)
% Synthesis Filter Bank: implements the synthesis filter bank for
% the overcomplete rational-dilation wavelet transform using the FFT.
%
% See also afb

% length of y:
N = length(lo)*q/p;    % equivalently N = length(hi)*s;

% filter low-pass subband:

Flo = fft(lo);
N0 = length(lo);
if rem(N0,2) == 0
    % N0 is even
    M = N0/2;
else
    % N0 is odd
    M = (N0+1)/2;
end
H(1:M) = H(1:M) .* Flo(1:M)/p;
H(N-N0+M+1:N) = H(N-N0+M+1:N) .* Flo(M+1:N0)/p;

% filter high-pass subbband:

N1 = length(hi);
% use the fact that G is zero except from (s-1)pi/s to (s+1)pi/s
if rem(s,2) == 0
    % s is even
    Fhi = fft(hi);
    k = (s/2-1)*N1;
    G(k+(1:N1)) = G(k+(1:N1)) .* Fhi;
    k = s/2*N1; 
    G(k+(1:N1)) = G(k+(1:N1)) .* Fhi;
else
    % s is odd
    k = (s-1)/2*N1; 
    G(k+(1:N1)) = G(k+(1:N1)) .* fft(hi);
end

y = ifft(H + G);
