function [lo, hi] = afb(x, H, G, p, q, s)
% [lo, hi] = afb(x, H, G, p, q, s)
% Analsysis Filter Bank: implements the analysis filter bank for
% the overcomplete rational-dilation wavelet transform using the FFT.
% INPUT
%   x - input signal
%   H, G - low-pass and high-pass frequency response
%   q/p - dilation factor
%   s - high-pass channel rate
% OUTPUT
%   lo, hi - low-pass, high-pass output signals
% NEED
%   length(x) = multiple of lcm(q,s)
%   length(H) = p*length(x)
%   length(G) = length(x)
%   redundancy = 1/s * 1/(1-p/q) > 1
%   (No error checking done)
%
% Ivan Selesnick and Ilker Bayram
% Polytechnic Institute, New York
% November 2008
%
% % Example (check perfect reconstruction)
% p = 4;
% q = 5;
% s = 2;
% N = 7*q*s;
% [H,G] = MakeFreqResp(N, p, q, s);
% x = rand(1,N);
% [lo,hi] = afb(x, H, G, p, q, s);
% y = sfb(lo, hi, H, G, p, q, s);
% y = y(1:N);
% max(abs(x - y))    % reconstruction error ~ 0

% up-sample input signal
x0 = zeros(1,length(x)*p);
x0(1:p:end) = x;

% low-pass subband
X0 = fft(x0);
lo = ifft(X0.*H);
lo = lo(1:q:end);

% high-pass subband
X = fft(x);
hi = ifft(X.*G);
hi = hi(1:s:end);

% Note: DFT properties can be exploited to 
% reduce the computation (up-sampling of input
% signal can be avoided).
